#!/bin/sh

set -e

# enter the current directory
cd "$(dirname $0)"
export PANDOC_DIR="/pandoc/cl"


if [ -z $1 ]; then
  export target=pdf
else
  export target=$1
fi

if [ -z $2 ]; then
  export kind=user
else
  export kind=$2
fi

if [ $kind = 'user' ]; then
  export files="
    intro.md
    concept.md
    interface.md
    search.md
    person.md
    person-vendee.md
    activite.md
    document.md
    thirdparty.md
    menage.md
    parcours.md
    social_actions.md
    notifications.md
    tasks.md
    workflows.md
    adresses.md
    exports.md
    nouveautes.md
  "
elif [ $kind = 'admin' ]; then
  export files="
    start.md
    generation-documents.md
  "
else
  echo "kind '$kind' is not valid";
  exit 1;
fi

cd $kind

export ARGS="
  --from markdown
  --number-sections
  --resource-path ./.
  --metadata-file ./metadata.yaml
  `#--lua-filter "../${PANDOC_DIR}/format-link.lua`
"
export PDF_TEMPLATE="./../pandoc/template/eisvogel.tex"
export LATEX_ARGS="
  --metadata=footer-left:$(date +%d-%m-%Y)
  --template "${PDF_TEMPLATE}"
  --lua-filter "../${PANDOC_DIR}/boxes.lua"
"


if [ $target = "latex" ]; then
  pandoc $ARGS $LATEX_ARGS \
    --to latex \
    $files;
elif [ $target = "pdf" ]; then
  pandoc $ARGS $LATEX_ARGS \
    --to pdf \
    --pdf-engine xelatex \
    -o "./../$kind-manual.pdf" \
    $files
elif [ $target = "html" ]; then
  # check target directory exists
  if [ ! -d "./../build/html" ]; then
    echo "create build/html directory"
    mkdir -p "./../build/html"
  fi

  pandoc $ARGS \
   --to html \
   -o ./../build/html/index.html \
  $files
fi

